import typing
import collections.abc
import typing_extensions

def RKS_GEN_available(_ksi, _context, ks, data): ...
def RKS_GEN_bendy_bones(_ksi, _context, ks, data): ...
def RKS_GEN_custom_props(_ksi, _context, ks, data): ...
def RKS_GEN_location(_ksi, _context, ks, data): ...
def RKS_GEN_rotation(_ksi, _context, ks, data): ...
def RKS_GEN_scaling(_ksi, _context, ks, data): ...
def RKS_ITER_selected_bones(ksi, context, ks): ...
def RKS_ITER_selected_item(ksi, context, ks): ...
def RKS_ITER_selected_objects(ksi, context, ks): ...
def RKS_POLL_selected_bones(_ksi, context): ...
def RKS_POLL_selected_items(ksi, context): ...
def RKS_POLL_selected_objects(_ksi, context): ...
def get_transform_generators_base_info(data): ...
def path_add_property(path, prop): ...
